@@ -11,8 +11,8 @@ class ModelService:
 
     def sample_source(self, workspace_id, query, num_rows):
         data = { 'workspaceId': workspace_id, 'query':  query, 'numRows': num_rows }
-        return self.client.http_post("/api/createview/get_preview_raw", data=data)
+        return self.client.http_post("/api/view/get_preview_raw", data=data)
 
     def get_schema(self, workspace_id, query):
         data = { 'workspaceId': workspace_id, 'query':  query }
-        return self.client.http_post("/api/createview/get_schema_of_query", data=data)
+        return self.client.http_post("/api/view/get_schema_of_query", data=data)
